package com.sun.jmx.snmp.IPAcl;

import java.net.UnknownHostException;
import java.util.Enumeration;
import java.security.acl.Permission;
import java.util.Vector;
import java.security.Principal;
import java.io.Serializable;
import java.security.acl.AclEntry;

class AclEntryImpl implements AclEntry, Serializable
{
    private static final long serialVersionUID = -5047185131260073216L;
    private Principal princ;
    private boolean neg;
    private Vector<Permission> permList;
    private Vector<String> commList;
    
    private AclEntryImpl(AclEntryImpl aclEntryImpl) throws UnknownHostException {
        this.princ = null;
        this.neg = false;
        this.permList = null;
        this.commList = null;
        this.setPrincipal(aclEntryImpl.getPrincipal());
        this.permList = new Vector();
        this.commList = new Vector();
        Enumeration<String> communities = aclEntryImpl.communities();
        while (communities.hasMoreElements()) {
            this.addCommunity((String)communities.nextElement());
        }
        Enumeration<Permission> permissions = aclEntryImpl.permissions();
        while (permissions.hasMoreElements()) {
            this.addPermission((Permission)permissions.nextElement());
        }
        if (aclEntryImpl.isNegative()) {
            this.setNegativePermissions();
        }
    }
    
    public AclEntryImpl() {
        this.princ = null;
        this.neg = false;
        this.permList = null;
        this.commList = null;
        this.princ = null;
        this.permList = new Vector();
        this.commList = new Vector();
    }
    
    public AclEntryImpl(Principal princ) throws UnknownHostException {
        this.princ = null;
        this.neg = false;
        this.permList = null;
        this.commList = null;
        this.princ = princ;
        this.permList = new Vector();
        this.commList = new Vector();
    }
    
    public Object clone() {
        AclEntryImpl aclEntryImpl;
        try {
            aclEntryImpl = new AclEntryImpl(this);
        }
        catch (UnknownHostException ex) {
            aclEntryImpl = null;
        }
        return aclEntryImpl;
    }
    
    public boolean isNegative() {
        return this.neg;
    }
    
    public boolean addPermission(Permission permission) {
        if (this.permList.contains(permission)) {
            return false;
        }
        this.permList.addElement(permission);
        return true;
    }
    
    public boolean removePermission(Permission permission) {
        if (!this.permList.contains(permission)) {
            return false;
        }
        this.permList.removeElement(permission);
        return true;
    }
    
    public boolean checkPermission(Permission o) {
        return this.permList.contains(o);
    }
    
    public Enumeration<Permission> permissions() {
        return this.permList.elements();
    }
    
    public void setNegativePermissions() {
        this.neg = true;
    }
    
    public Principal getPrincipal() {
        return this.princ;
    }
    
    public boolean setPrincipal(Principal princ) {
        if (this.princ != null) {
            return false;
        }
        this.princ = princ;
        return true;
    }
    
    @Override
    public String toString() {
        return "AclEntry:" + this.princ.toString();
    }
    
    public Enumeration<String> communities() {
        return this.commList.elements();
    }
    
    public boolean addCommunity(String s) {
        if (this.commList.contains(s)) {
            return false;
        }
        this.commList.addElement(s);
        return true;
    }
    
    public boolean removeCommunity(String s) {
        if (!this.commList.contains(s)) {
            return false;
        }
        this.commList.removeElement(s);
        return true;
    }
    
    public boolean checkCommunity(String o) {
        return this.commList.contains(o);
    }
}
